@@ -33,7 +33,7 @@ void warningcall (SEXP call, char *format, ...);
 
 static herr_t
 ref_string (hid_t sid, hid_t did, H5T_cdata_t *cdata,
-	    size_t count, size_t stride,
+	    size_t count, size_t stride, size_t bkg_stride,
 	    void *buf, void *bkg,
 	    hid_t dset_xfer_plid)
 {
@@ -59,7 +59,7 @@ ref_string (hid_t sid, hid_t did, H5T_cdata_t *cdata,
 
 static herr_t
 string_ref (hid_t sid, hid_t did, H5T_cdata_t *cdata,
-	    size_t count, size_t stride,
+	    size_t count, size_t stride, size_t bkg_stride,
 	    void *buf, void *bkg,
 	    hid_t dset_xfer_plid)
 {
